@@ -3,14 +3,14 @@ BEGIN {
   $POE::Component::IRC::Plugin::AutoJoin::AUTHORITY = 'cpan:HINRIK';
 }
 BEGIN {
-  $POE::Component::IRC::Plugin::AutoJoin::VERSION = '6.60';
+  $POE::Component::IRC::Plugin::AutoJoin::VERSION = '6.61';
 }
 
 use strict;
 use warnings FATAL => 'all';
 use Carp;
+use IRC::Utils qw(parse_user lc_irc);
 use POE::Component::IRC::Plugin qw(:ALL);
-use POE::Component::IRC::Common qw(parse_user l_irc);
 
 sub new {
     my ($package) = shift;
@@ -25,7 +25,9 @@ sub PCI_register {
     if (!$self->{Channels}) {
         if ($irc->isa('POE::Component::IRC::State')) {
             for my $chan (keys %{ $irc->channels() }) {
-                my $lchan = l_irc($chan, $irc->isupport('MAPPING'));
+                my $lchan = lc_irc($chan, $irc->isupport('MAPPING'));
+                # note that this will not get the real key on ircu servers
+                # in channels where we don't have ops
                 my $key = $irc->is_channel_mode_set($chan, 'k')
                     ? $irc->channel_key($chan)
                     : ''
@@ -40,14 +42,14 @@ sub PCI_register {
     }
     elsif (ref $self->{Channels} eq 'ARRAY') {
         my %channels;
-        $channels{l_irc($_, $irc->isupport('MAPPING'))} = undef for @{ $self->{Channels} };
+        $channels{lc_irc($_, $irc->isupport('MAPPING'))} = undef for @{ $self->{Channels} };
         $self->{Channels} = \%channels;
     }
 
     $self->{tried_keys} = { };
     $self->{Rejoin_delay} = 5 if !defined $self->{Rejoin_delay};
     $self->{NickServ_delay} = 5 if !defined $self->{NickServ_delay};
-    $irc->plugin_register($self, 'SERVER', qw(001 004 474 isupport chan_mode join kick part identified));
+    $irc->plugin_register($self, 'SERVER', qw(001 474 isupport chan_mode join kick part identified));
     $irc->plugin_register($self, 'USER', qw(join));
     return 1;
 }
@@ -58,22 +60,10 @@ sub PCI_unregister {
 
 sub S_001 {
     my ($self, $irc) = splice @_, 0, 2;
-    delete $self->{masked_key};
     delete $self->{alarm_ids};
     return PCI_EAT_NONE;
 }
 
-# RPL_MYINFO
-sub S_004 {
-    my ($self, $irc) = splice @_, 0, 2;
-    my $version = ${ $_[2] }->[1];
-
-    # ircu returns '*' to non-ops instead of the real channel key
-    $self->{masked_key} = 1 if $version =~ /^u\d/;
-
-    return PCI_EAT_NONE;
-}
-
 # we join channels after S_isupport in case the server supports
 # CAPAB IDENTIFY-MSG, so pocoirc can turn it on before we join channels
 sub S_isupport {
@@ -114,7 +104,7 @@ sub S_identified {
 sub S_474 {
     my ($self, $irc) = splice @_, 0, 2;
     my $chan = ${ $_[2] }->[0];
-    my $lchan = l_irc($chan, $irc->isupport('MAPPING'));
+    my $lchan = lc_irc($chan, $irc->isupport('MAPPING'));
     return PCI_EAT_NONE if !$self->{Retry_when_banned};
 
     my $key = $self->{Channels}{$lchan};
@@ -129,7 +119,7 @@ sub S_chan_mode {
     my $chan  = ${ $_[1] };
     my $mode  = ${ $_[2] };
     my $arg   = defined $_[3] ? ${ $_[3] } : '';
-    my $lchan = l_irc($chan, $irc->isupport('MAPPING'));
+    my $lchan = lc_irc($chan, $irc->isupport('MAPPING'));
 
     $self->{Channels}->{$lchan} = $arg if $mode eq '+k';
     $self->{Channels}->{$lchan} = '' if $mode eq '-k';
@@ -140,7 +130,7 @@ sub S_join {
     my ($self, $irc) = splice @_, 0, 2;
     my $joiner = parse_user(${ $_[0] });
     my $chan   = ${ $_[1] };
-    my $lchan  = l_irc($chan, $irc->isupport('MAPPING'));
+    my $lchan  = lc_irc($chan, $irc->isupport('MAPPING'));
 
     return PCI_EAT_NONE if $joiner ne $irc->nick_name();
     delete $self->{alarm_ids};
@@ -160,7 +150,7 @@ sub S_kick {
     my ($self, $irc) = splice @_, 0, 2;
     my $chan   = ${ $_[1] };
     my $victim = ${ $_[2] };
-    my $lchan  = l_irc($chan, $irc->isupport('MAPPING'));
+    my $lchan  = lc_irc($chan, $irc->isupport('MAPPING'));
 
     if ($victim eq $irc->nick_name()) {
         if ($self->{RejoinOnKick}) {
@@ -179,7 +169,7 @@ sub S_part {
     my ($self, $irc) = splice @_, 0, 2;
     my $parter = parse_user(${ $_[0] });
     my $chan   = ${ $_[1] };
-    my $lchan  = l_irc($chan, $irc->isupport('MAPPING'));
+    my $lchan  = lc_irc($chan, $irc->isupport('MAPPING'));
 
     delete $self->{Channels}->{$lchan} if $parter eq $irc->nick_name();
     return PCI_EAT_NONE;
@@ -188,7 +178,7 @@ sub S_part {
 sub U_join {
     my ($self, $irc) = splice @_, 0, 2;
     my (undef, $chan, $key) = split /\s/, ${ $_[0] }, 3;
-    my $lchan = l_irc($chan, $irc->isupport('MAPPING'));
+    my $lchan = lc_irc($chan, $irc->isupport('MAPPING'));
 
     $self->{tried_keys}->{$lchan} = $key if defined $key;
     return PCI_EAT_NONE;
