@@ -3,14 +3,14 @@ BEGIN {
   $POE::Component::IRC::Plugin::PlugMan::AUTHORITY = 'cpan:HINRIK';
 }
 BEGIN {
-  $POE::Component::IRC::Plugin::PlugMan::VERSION = '6.60';
+  $POE::Component::IRC::Plugin::PlugMan::VERSION = '6.61';
 }
 
 use strict;
 use warnings FATAL => 'all';
 use Carp;
+use IRC::Utils qw( matches_mask parse_user );
 use POE::Component::IRC::Plugin qw( :ALL );
-use POE::Component::IRC::Common qw( matches_mask parse_user );
 
 BEGIN {
     # Turn on the debugger's symbol source tracing
