@@ -3,14 +3,14 @@ BEGIN {
   $POE::Component::IRC::Plugin::Whois::AUTHORITY = 'cpan:HINRIK';
 }
 BEGIN {
-  $POE::Component::IRC::Plugin::Whois::VERSION = '6.60';
+  $POE::Component::IRC::Plugin::Whois::VERSION = '6.61';
 }
 
 use strict;
 use warnings FATAL => 'all';
 use POE;
 use POE::Component::IRC::Plugin qw( PCI_EAT_NONE );
-use POE::Component::IRC::Common qw(:ALL);
+use IRC::Utils qw(uc_irc);
 
 sub new {
     return bless { }, shift;
@@ -33,7 +33,7 @@ sub S_311 {
     my @args = @{ ${ $_[2] } };
     my $real = pop @args;
     my ($rnick,$user,$host) = @args;
-    my $nick = u_irc $rnick, $mapping;
+    my $nick = uc_irc $rnick, $mapping;
 
     $self->{WHOIS}->{ $nick }->{nick} = $rnick;
     $self->{WHOIS}->{ $nick }->{user} = $user;
@@ -47,7 +47,7 @@ sub S_311 {
 sub S_313 {
     my ($self, $irc) = splice @_, 0, 2;
     my $mapping = $irc->isupport('CASEMAPPING');
-    my $nick = u_irc ${ $_[2] }->[0], $mapping;
+    my $nick = uc_irc ${ $_[2] }->[0], $mapping;
     my $oper = ${ $_[2] }->[1];
 
     $self->{WHOIS}->{ $nick }->{oper} = $oper;
@@ -59,7 +59,7 @@ sub S_312 {
     my ($self, $irc) = splice @_, 0, 2;
     my $mapping = $irc->isupport('CASEMAPPING');
     my ($nick,$server) = @{ ${ $_[2] } };
-    $nick = u_irc $nick, $mapping;
+    $nick = uc_irc $nick, $mapping;
 
     # This can be returned in reply to either a WHOIS or a WHOWAS *sigh*
     if ( defined $self->{WHOWAS}->{ $nick } ) {
@@ -77,7 +77,7 @@ sub S_317 {
     my ($self, $irc) = splice @_, 0, 2;
     my $mapping = $irc->isupport('CASEMAPPING');
     my ($nick,@args) = @{ ${ $_[2] } };
-    $nick = u_irc $nick, $mapping;
+    $nick = uc_irc $nick, $mapping;
 
     $self->{WHOIS}->{ $nick }->{idle} = $args[0];
     $self->{WHOIS}->{ $nick }->{signon} = $args[1];
@@ -90,7 +90,7 @@ sub S_319 {
     my ($self, $irc) = splice @_, 0, 2;
     my $mapping = $irc->isupport('CASEMAPPING');
     my @args = @{ ${ $_[2] } };
-    my $nick = u_irc shift ( @args ), $mapping;
+    my $nick = uc_irc shift ( @args ), $mapping;
     my @chans = split / /, shift @args;
 
     if ( !defined $self->{WHOIS}->{ $nick }->{channels} ) {
@@ -109,7 +109,7 @@ sub S_320 {
     my $mapping = $irc->isupport('CASEMAPPING');
     my ($nick, $ident) = @{ ${ $_[2] } };
 
-    $self->{WHOIS}->{ u_irc ( $nick, $mapping  ) }->{identified} = $ident;
+    $self->{WHOIS}->{ uc_irc ( $nick, $mapping  ) }->{identified} = $ident;
 
     return PCI_EAT_NONE;
 }
@@ -118,7 +118,7 @@ sub S_320 {
 sub S_338 {
     my ($self, $irc) = splice @_, 0, 2;
     my $mapping = $irc->isupport('CASEMAPPING');
-    my $nick = u_irc ${ $_[2] }->[0], $mapping;
+    my $nick = uc_irc ${ $_[2] }->[0], $mapping;
     my $ip = ${ $_[2] }->[1];
 
     $self->{WHOIS}->{ $nick }->{actually} = $ip;
@@ -132,7 +132,7 @@ sub S_330 {
     my $mapping = $irc->isupport('CASEMAPPING');
     my ($nick,$account) = @{ ${ $_[2] } };
 
-    $self->{WHOIS}->{ u_irc ( $nick, $mapping ) }->{account} = $account;
+    $self->{WHOIS}->{ uc_irc ( $nick, $mapping ) }->{account} = $account;
 
     return PCI_EAT_NONE;
 }
@@ -142,10 +142,10 @@ sub S_330 {
 sub S_318 {
     my ($self, $irc) = splice @_, 0, 2;
     my $mapping = $irc->isupport('CASEMAPPING');
-    my $nick = u_irc ${ $_[2] }->[0], $mapping;
+    my $nick = uc_irc ${ $_[2] }->[0], $mapping;
     my $whois = delete $self->{WHOIS}->{ $nick };
 
-    $irc->send_event( 'irc_whois', $whois ) if defined $whois;
+    $irc->send_event_next( 'irc_whois', $whois ) if defined $whois;
     return PCI_EAT_NONE;
 }
 
@@ -156,7 +156,7 @@ sub S_314 {
     my @args = @{ ${ $_[2] } };
     my $real = pop @args;
     my ($rnick,$user,$host) = @args;
-    my $nick = u_irc $rnick, $mapping;
+    my $nick = uc_irc $rnick, $mapping;
 
     $self->{WHOWAS}->{ $nick }->{nick} = $rnick;
     $self->{WHOWAS}->{ $nick }->{user} = $user;
@@ -170,10 +170,10 @@ sub S_314 {
 sub S_369 {
     my ($self, $irc) = splice @_, 0, 2;
     my $mapping = $irc->isupport('CASEMAPPING');
-    my $nick = u_irc ${ $_[2] }->[0], $mapping;
+    my $nick = uc_irc ${ $_[2] }->[0], $mapping;
 
     my $whowas = delete $self->{WHOWAS}->{ $nick };
-    $irc->send_event( 'irc_whowas', $whowas ) if defined $whowas;
+    $irc->send_event_next( 'irc_whowas', $whowas ) if defined $whowas;
     return PCI_EAT_NONE;
 }
 
